@@ -11,20 +11,16 @@ Runner
    :toctree: generated/
    :nosignatures:
 
-   run
+   fab_run
 
-Procedures
+Client
 ==========
 
 .. autosummary::
    :toctree: generated/
    :nosignatures:
 
-   pre_procedure
-   post_procedure
-   pick_bullet
-   place_bullet
-   grip_and_release
+   AbbRcfClient
 
 Utilities
 =========
@@ -34,8 +30,7 @@ Utilities
    :nosignatures:
 
    RapidToolData
-   ping
-   check_reconnect
+   standalone_move_to_frame
 """
 from __future__ import absolute_import
 from __future__ import division
@@ -43,8 +38,10 @@ from __future__ import print_function
 
 from compas import IPY
 
-from .helpers import *  # noqa: F401,F403
+from .compas_rrc_docker_setup import *  # noqa: F401,F403
 from .rapid_tool_data import *  # noqa: F401,F403
+from .standalone_move_to_frame import *  # noqa: F401,F403
 
 if not IPY:
     from .abb_rcf_client import *  # noqa: F401,F403
+    from .fab_run import fab_run  # noqa: F401
