@@ -13,9 +13,6 @@ Fabrication datastructures
     :toctree: generated/
     :nosignatures:
 
-    ClayBullet
-    ClayStructure
-
 Fabrication configuration
 -------------------------
 
@@ -30,19 +27,12 @@ format. Here is the default config:
     :toctree: generated/
     :nosignatures:
 
-    interactive_conf_setup
-
 Tools & Utilities
 -----------------
 
 .. autosummary::
     :toctree: generated/
     :nosignatures:
-
-    csv_reports
-    load_bullets
-    ClayBulletEncoder
-    check_id_collision
 """
 from __future__ import absolute_import
 from __future__ import division
@@ -50,10 +40,8 @@ from __future__ import print_function
 
 from compas import IPY
 
-from .clay_objs import *  # noqa: F401,F403
-from .csv_report import *  # noqa: F401,F403
+from .fabrication_element import *  # noqa: F401,F403
 from .pick_station import *  # noqa: F401,F403
-from .tools import *  # noqa: F401,F403
 
 if not IPY:
     from .fab_conf import *  # noqa: F401,F403
